diff --git a/include/vlc_picture.h b/include/vlc_picture.h
index f264d76..40143e8 100644
--- a/include/vlc_picture.h
+++ b/include/vlc_picture.h
@@ -61,6 +61,13 @@ typedef struct plane_t
  */
 typedef struct picture_release_sys_t picture_release_sys_t;
 
+/* A bit flag for i_eye that indicates to wait for the next frame before
+   presenting. */
+#define STEREO_WAIT_FOR_NEXT_FRAME_BIT (1 << 8)
+
+/* Mask the lower bits of i_eye to return the eye that should be drawn. */
+#define STEREO_EYE_MASK 0xFF
+
 /**
  * Video picture
  */
@@ -75,6 +82,15 @@ struct picture_t
     plane_t         p[PICTURE_PLANE_MAX];     /**< description of the planes */
     int             i_planes;                /**< number of allocated planes */
 
+    /** \name Stereoscopy properties
+     **@{*/
+    int             i_eye;                /**< the stereoscopy eye, may be:
+                                                0 - 2d image,
+                                                1- left eye,
+                                                2 - right eye - could possibly be > 2 for more
+                                                    than 2 eyes */
+    /**@}*/
+
     /** \name Picture management properties
      * These properties can be modified using the video output thread API,
      * but should never be written directly */
@@ -100,6 +116,7 @@ struct picture_t
      * keep track of the picture */
     picture_sys_t * p_sys;
 
+
     /** This way the picture_Release can be overloaded */
     void (*pf_release)( picture_t * );
     picture_release_sys_t *p_release_sys;
@@ -216,6 +233,7 @@ static inline void picture_CopyProperties( picture_t *p_dst, const picture_t *p_
     p_dst->i_nb_fields = p_src->i_nb_fields;
     p_dst->b_top_field_first = p_src->b_top_field_first;
 
+    p_dst->i_eye = p_src->i_eye; /* for stereoscopy */
     /* FIXME: copy ->p_q and ->p_qstride */
 }
 
diff --git a/include/vlc_vout_display.h b/include/vlc_vout_display.h
index 77d66e2..c5bae9d 100644
--- a/include/vlc_vout_display.h
+++ b/include/vlc_vout_display.h
@@ -171,6 +171,10 @@ enum {
      * video_format_t::i_visible_width/height */
     VOUT_DISPLAY_CHANGE_SOURCE_CROP,   /* const video_format_t *p_source */
 
+	/* Ask the module to acknowledge/refuse source stereoscopy format change after being
+	 * requested externally */
+    VOUT_DISPLAY_CHANGE_STEREOSCOPY,
+
     /* Ask an opengl interface if available. */
     VOUT_DISPLAY_GET_OPENGL,           /* vlc_gl_t ** */
 };
diff --git a/modules/gui/qt4/components/extended_panels.cpp b/modules/gui/qt4/components/extended_panels.cpp
index f7ab8a3..9f566a3 100644